==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/MonitorUI/src/com/clustercontrol/monitor/view/StatusView.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.view;

import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;

import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.bean.Property;
import com.clustercontrol.monitor.composite.StatusListComposite;
import com.clustercontrol.monitor.preference.MonitorPreferencePage;
import com.clustercontrol.monitor.ui.MonitorUIPlugin;
import com.clustercontrol.monitor.view.action.StatusDeleteAction;
import com.clustercontrol.util.Messages;
import com.clustercontrol.view.ScopeListBaseView;

/**
 * ִƻ뵡ǽݥơƻӥ塼饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class StatusView extends ScopeListBaseView {
    public static final String ID = "com.clustercontrol.monitor.view.StatusView";

    //	 ----- instance ե ----- //

    /** ơƻݥå */
    private StatusListComposite tableComposite = null;

    /**  */
    private Property condition = null;

    //	 ----- 󥹥ȥ饯 ----- //

    //	 ----- instance ᥽å ----- //

    /**
     * ơơ֥ɲäޤ
     * 
     * @param parent
     *            ƤΥݥå
     * @return ơơ֥륳ݥå
     */
    protected Composite createListContents(Composite parent) {
        GridLayout layout = new GridLayout(1, true);
        parent.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        this.tableComposite = new StatusListComposite(parent, SWT.NONE);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        this.tableComposite.setLayoutData(gridData);
        
        //ݥåץåץ˥塼
        createContextMenu();

        this.update();

        // ȿ
        IPreferenceStore store = MonitorUIPlugin.getDefault()
                .getPreferenceStore();

        this.setInterval(store
                .getInt(MonitorPreferencePage.P_STATUS_UPDATE_CYCLE));

        if (store.getBoolean(MonitorPreferencePage.P_STATUS_UPDATE_FLG)) {
            this.startAutoReload();
        }

        return this.tableComposite;
    }

    /**
     * 򤵤줿(Ρ)ξɽޤ
     * 
     * @param item
     *            ץĥ꡼ƥ
     */
    protected void doSelectTreeItem(FacilityTreeItem item) {
        // ȥܥ򸵤᤹
//        if (this.condition != null) {
//            IToolBarManager toolbar = this.getViewSite().getActionBars()
//                    .getToolBarManager();
//            String id = "com.clustercontrol.monitor.view.action.StatusFilterAction";
//            ActionContributionItem actionItem = (ActionContributionItem) toolbar
//                    .find(id);
//
//            actionItem.getAction().setChecked(false);
//            this.condition = null;
//        }

        this.update();
    }
    
    /**
     * ݥåץåץ˥塼
     * 
     *  
     */
    protected void createContextMenu() {
        MenuManager menuManager = new MenuManager();
        menuManager.setRemoveAllWhenShown(true);
        menuManager.addMenuListener(new IMenuListener() {
            /*
             * (non-Javadoc)
             * 
             * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
             */
            public void menuAboutToShow(IMenuManager manager) {
                //˥塼
                fillContextMenu(manager);
            }
        });

        Menu menu = menuManager.createContextMenu(tableComposite.getTable());
        tableComposite.getTable().setMenu(menu);
    }

    /**
     * ˥塼ɲ
     * 
     * @param manager
     */
    protected void fillContextMenu(IMenuManager manager) {
        //ӥ塼ΥΥ󥹥󥹤
        IToolBarManager toolbar = this.getViewSite().getActionBars()
                .getToolBarManager();
        ActionContributionItem deleteAction = (ActionContributionItem) toolbar
        		.find(StatusDeleteAction.ID);

        //ݥåץåץ˥塼˥ɲ
        manager.add(deleteAction.getAction());
    }

    /**
     * ӥ塼򹹿ޤ
     * <p>
     */
    public void update() {

        FacilityTreeItem item = this.getScopeTreeComposite().getSelectItem();
        String facilityId = null;
        if (item != null) {
            facilityId = item.getData().getFacilityId();
        }

        if (this.condition == null) {
            // ץĥ꡼ǥƥब򤵤Ƥʤ
            if (facilityId == null) {
                this.getPathLabel()
                        .setText(Messages.getString("scope") + " : ");
                this.getPathLabel().pack();
            }
            this.tableComposite.update(facilityId);
        } else {
            this.getPathLabel().setText(Messages.getString("filtered.list"));
            this.getPathLabel().pack();
            this.tableComposite.update(facilityId, this.condition);
        }
    }

    /**
     * ꤷޤ
     * <p>
     * 
     * updateϡθη̤ɽޤ
     * 
     * @param condition
     *            
     */
    public void setCondition(Property condition) {
        this.condition = condition;
    }

    /**
     * ȥӥ塼ޤ
     */
    public void dispose() {
        super.dispose();

        this.setCondition(null);
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/MonitorUI/src/com/clustercontrol/monitor/view/StatusView.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.view;

import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;

import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.bean.Property;
import com.clustercontrol.monitor.composite.StatusListComposite;
import com.clustercontrol.monitor.preference.MonitorPreferencePage;
import com.clustercontrol.monitor.ui.MonitorUIPlugin;
import com.clustercontrol.monitor.view.action.StatusDeleteAction;
import com.clustercontrol.util.Messages;
import com.clustercontrol.view.ScopeListBaseView;

/**
 * 監視[ステータス]ビュークラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class StatusView extends ScopeListBaseView {
	
	/** 監視[ステータス]ビューID */
    public static final String ID = "com.clustercontrol.monitor.view.StatusView";

    /** ステータス情報一覧コンポジット */
    private StatusListComposite tableComposite = null;

    /** 検索条件 */
    private Property condition = null;


    /**
     * ステータス情報一覧テーブルを作成・追加します。
     * <p>
	 * <ol>
	 * <li>ステータス情報一覧テーブルを取得します。</li>
	 * <li>ステータス情報一覧テーブルに、ポップアップメニューを追加します。</li>
	 * <li>ビューを更新します。</li>
	 * <li>プレファレンスページの設定より、監視[ステータス]ビューの自動更新周期を取得し、このビューにセットします。</li>
	 * <li>プレファレンスページの設定より、監視[ステータス]ビューの自動更新フラグを取得し、このビューにセットします。</li>
	 * <li>ステータス情報一覧テーブルを返します。</li>
	 * </ol>
	 * 
     * @param parent 親のコンポジット
     * @return ステータス情報一覧テーブルコンポジット
     * 
     * @see com.clustercontrol.monitor.composite.StatusListComposite#StatusListComposite(Composite, int)
     * @see #createContextMenu()
     * @see #update()
     */
    protected Composite createListContents(Composite parent) {
        GridLayout layout = new GridLayout(1, true);
        parent.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        this.tableComposite = new StatusListComposite(parent, SWT.NONE);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        this.tableComposite.setLayoutData(gridData);
        
        //ポップアップメニュー作成
        createContextMenu();

        this.update();

        // 設定情報反映
        IPreferenceStore store = MonitorUIPlugin.getDefault()
                .getPreferenceStore();

        this.setInterval(store
                .getInt(MonitorPreferencePage.P_STATUS_UPDATE_CYCLE));

        if (store.getBoolean(MonitorPreferencePage.P_STATUS_UPDATE_FLG)) {
            this.startAutoReload();
        }

        return this.tableComposite;
    }

    /**
     * スコープツリーでアイテムを選択した際に呼ばれ、ビューを更新します。
     * 
     * @param item スコープツリーアイテム
     * 
     * @see #update()
     */
    protected void doSelectTreeItem(FacilityTreeItem item) {
        // 検索トグルボタンを元に戻す。
//        if (this.condition != null) {
//            IToolBarManager toolbar = this.getViewSite().getActionBars()
//                    .getToolBarManager();
//            String id = "com.clustercontrol.monitor.view.action.StatusFilterAction";
//            ActionContributionItem actionItem = (ActionContributionItem) toolbar
//                    .find(id);
//
//            actionItem.getAction().setChecked(false);
//            this.condition = null;
//        }

        this.update();
    }
    
    /**
     * ポップアップメニューを作成します。
     */
    protected void createContextMenu() {
        MenuManager menuManager = new MenuManager();
        menuManager.setRemoveAllWhenShown(true);
        menuManager.addMenuListener(new IMenuListener() {
            /*
             * (non-Javadoc)
             * 
             * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
             */
            public void menuAboutToShow(IMenuManager manager) {
                //メニュー項目設定
                fillContextMenu(manager);
            }
        });

        Menu menu = menuManager.createContextMenu(tableComposite.getTable());
        tableComposite.getTable().setMenu(menu);
    }

    /**
     * ポップアップメニューに項目を追加します。
     * 
     * @param manager ポップアップメニューオブジェクト
     */
    protected void fillContextMenu(IMenuManager manager) {
        //ビューのアクションのインスタンスを取得
        IToolBarManager toolbar = this.getViewSite().getActionBars()
                .getToolBarManager();
        ActionContributionItem deleteAction = (ActionContributionItem) toolbar
        		.find(StatusDeleteAction.ID);

        //ポップアップメニューにアクションを追加
        manager.add(deleteAction.getAction());
    }

    /**
     * ビューを更新します。<BR>
     * <p>
	 * <ol>
	 * <li>スコープツリーで選択されているアイテムを取得します。</li>
	 * <li>アイテムより、ファシリティIDを取得します。</li>
	 * <li>ファシリティIDをキーに、ステータス情報を更新します。
	 *     検索条件が<code>null</code>ではない場合は、検索条件も指定します。</li>
	 * </ol>
	 * 
	 * @see com.clustercontrol.composite.FacilityTreeComposite#getSelectItem()
	 * @see com.clustercontrol.bean.FacilityInfo#getFacilityId()
	 * @see com.clustercontrol.monitor.composite.StatusListComposite#update(String)
	 * @see com.clustercontrol.monitor.composite.StatusListComposite#update(String, Property)
     */
    public void update() {

        FacilityTreeItem item = this.getScopeTreeComposite().getSelectItem();
        String facilityId = null;
        if (item != null) {
            facilityId = item.getData().getFacilityId();
        }

        if (this.condition == null) {
            // スコープツリーでアイテムが選択されていない場合
            if (facilityId == null) {
                this.getPathLabel()
                        .setText(Messages.getString("scope") + " : ");
                this.getPathLabel().pack();
            }
            this.tableComposite.update(facilityId);
        } else {
            this.getPathLabel().setText(Messages.getString("filtered.list"));
            this.getPathLabel().pack();
            this.tableComposite.update(facilityId, this.condition);
        }
    }

    /**
     * 検索条件を設定します。
     * <p>
     * 
     * 設定後のupdateは、この検索条件の結果が表示されます。
     * 
     * @param condition
     *            検索条件
     */
    public void setCondition(Property condition) {
        this.condition = condition;
    }

    /**
     * 検索条件とビューアクションを初期化します。
     */
    public void dispose() {
        super.dispose();

        this.setCondition(null);
    }
}
